.. _api_dimse:

*************
DIMSE Service
*************

The DICOM Message Service Element (DIMSE) provides the mechanism for message
exchange between peer Application Entities once an Association between them
has been established.

.. toctree::
   :maxdepth: 3
   :includehidden:

   dimse.provider
   dimse.primitives
   dimse.messages
